@@ -14,6 +14,22 @@ CaptchaWindow::CaptchaWindow(QWidget *parent, QPixmap* captchaImage) :
 #ifdef Q_WS_MAEMO_5
     setAttribute(Qt::WA_Maemo5AutoOrientation, true);
 #endif
+
+#ifdef Q_OS_SYMBIAN
+    ui->btnOK->setVisible(false);
+
+    QAction* softKey = new QAction( tr("Ok"), this );
+    softKey->setSoftKeyRole( QAction::PositiveSoftKey );
+    connect(softKey, SIGNAL(triggered()), this, SLOT(OkSlot()));
+    addAction(softKey);
+
+    softKey = new QAction( tr("Annulla"), this );
+    softKey->setSoftKeyRole( QAction::NegativeSoftKey );
+    connect(softKey, SIGNAL(triggered()), this, SLOT(reject()));
+    addAction(softKey);
+#endif
+
+    ui->txtCaptcha->grabKeyboard();
 }
 
 CaptchaWindow::~CaptchaWindow()
