@@ -11,6 +11,9 @@ public:
 
     static bool IsPortrait();
     static QString GetHomeFolder();
+    static QString FormatKBytes(int kbytes);
+
+    static bool IsMouseOver(QWidget* w);
 };
 
 #endif // COMMONSTATIC_H
