@@ -33,6 +33,7 @@ private:
     QAction* m_AboutAction;
     QAction* m_QuitAction;
     QAction* m_UpdateAction;
+    QAction* m_SelectSimAction;
 
     VodafoneWidget* m_Vodafone;
     QList<Counter*>* m_Counters;
@@ -48,6 +49,7 @@ private slots:
     void QuitSlot();
     void SmsSlot();
     void UpdateSlot();
+    void SelectSIMSlot();
 };
 
 #endif // MAINWINDOW_H
