@@ -17,7 +17,7 @@ public:
     QDate Scadenza;
 
     QString ToString();
-    void FromString(QString string);
+    bool FromString(QString string);
 signals:
 
 public slots:
