@@ -2,6 +2,7 @@
 
 VodafoneWidget::VodafoneWidget(QString username, QString password)
 {    
+    m_CurrentSimType = SimUnknown;
     m_Aborting = false;
     m_CurrentReply = NULL;
     DebugXml = false;
@@ -49,6 +50,41 @@ bool VodafoneWidget::IsLoggedIn()
     if (!sessionID.isNull())
         m_SessionID = sessionID.firstChild().nodeValue();
 
+    //Read all the sims:
+    if (result){
+        m_Sims.clear();
+        QDomNode user = root.firstChildElement("user");
+        QDomNode sims = user.firstChildElement("all-sims");
+        if (!sims.isNull()){
+            QDomNodeList list = sims.childNodes();
+            for (int i=0; i<list.count(); i++){
+                QDomNode node = list.at(i);
+                if (node.nodeName() == "msisdn")
+                    m_Sims.append(node.firstChild().nodeValue());
+            }
+        }
+
+        QDomNode sim = user.firstChildElement("current-msisdn");
+        if (!sim.isNull())
+            m_CurrentSim = sim.firstChild().nodeValue();
+
+        QDomNode qualifiers = user.firstChildElement("all-user-qualifiers");
+        if (!qualifiers.isNull()){
+            QDomNodeList list = qualifiers.childNodes();
+            for (int i=0; i<list.count(); i++){
+                QDomNode node = list.at(i);
+                QDomNode name = node.firstChildElement("qual-name");
+                QDomNode value = node.firstChildElement("qual-value");
+                if (!name.isNull() && !value.isNull() && name.firstChild().nodeValue() == "Tipo SIM"){
+                    if (value.firstChild().nodeValue() == "ricaricabile")
+                        m_CurrentSimType = SimRicaricabile;
+                    else
+                        m_CurrentSimType = SimContratto;
+                    break;
+                }
+            }
+        }
+    }
     return result;
 } // IsLoggedIn
 
@@ -170,6 +206,42 @@ float VodafoneWidget::GetCredito(QString* valuta)
     return result;
 } // GetCredito
 
+bool VodafoneWidget::GetInfoConto(InfoConto* info)
+{
+    QNetworkRequest request = PrepareRequest("https://widget.vodafone.it/190/ebwe/mx/PushInfoconto.do?hpfdtpri=y");
+    QString string = SynchRequest(&request);
+    if (DebugXml)
+        qDebug() << "GetInfoConto: " << string;
+
+    QDomDocument doc("response");
+    doc.setContent(string);
+
+    QDomNode root = doc.firstChildElement("root");
+    QDomNodeList list = root.childNodes();
+    int found = 0;
+    for (int i=0; i<list.count(); i++){
+        QDomNode node = list.at(i);
+        if (node.nodeName() == "e"){
+            QDomNode name = node.attributes().namedItem("n");
+            if (name.nodeValue() == "TRAFFICO_NON_FATTURATO"){
+                QDomNode val = node.attributes().namedItem("v");
+                QString credito = val.nodeValue();
+                info->TrafficoNonFatturato = credito.toFloat();
+                found++;
+            }else if (name.nodeValue() == "DATA_ULTIMA_FATTURAZIONE"){
+                QDomNode val = node.attributes().namedItem("v");
+                QString data = val.nodeValue();
+                info->DataUltimaFatturazione = QDate::fromString(data, "yyyy-MM-dd hh:mm:ss");
+                found++;
+            }
+        }
+        if (found >= 2)
+            break;
+    }
+
+    return true;
+}
+
 QList<Counter*>* VodafoneWidget::GetListaContatori()
 {
     QList<Counter*>* result = new QList<Counter*>();
@@ -239,22 +311,25 @@ bool VodafoneWidget::GetDettaglioContatore(Counter* counter)
     for (int i=0; i<list.count(); i++){
         QDomNode node = list.at(i);
         if (node.nodeName() == "Soglia"){
-            counter->Soglia = node.firstChild().nodeValue().toInt();
+            counter->Soglia = node.firstChild().nodeValue().toFloat();
             found++;
         }else if (node.nodeName() == "DisplayType"){
             counter->SogliaDisplayType = node.firstChild().nodeValue().toInt();
             found++;
         }else if (node.nodeName() == "TrafficoUtilizzato"){
-            counter->Utilizzato = node.firstChild().nodeValue().toInt();
+            counter->Utilizzato = node.firstChild().nodeValue().toFloat();
             found++;
         }else if (node.nodeName() == "TrafficoResiduo"){
-            counter->Residuo = node.firstChild().nodeValue().toInt();
+            counter->Residuo = node.firstChild().nodeValue().toFloat();
             found++;
         }else if (node.nodeName() == "DimensioneScatto"){
             counter->DimensioneScatto = node.firstChild().nodeValue();
             found++;
+        }else if (node.nodeName() == "UnitaContatore"){
+            counter->Unita = node.firstChild().nodeValue();
+            found++;
         }else if (node.nodeName() == "UnitaScatto"){
-            counter->Scatto = node.firstChild().nodeValue().toInt();
+            counter->Scatto = node.firstChild().nodeValue().toFloat();
             found++;
         }else if (node.nodeName() == "Periodo"){
             counter->Periodo = QDate::fromString(node.firstChild().nodeValue(), "dd/MM/yyyy");
@@ -264,7 +339,7 @@ bool VodafoneWidget::GetDettaglioContatore(Counter* counter)
             found++;
         }
 
-        if (found == 8)
+        if (found == 9)
             break;
     }
 
@@ -429,58 +504,58 @@ QString VodafoneWidget::Decrypt(QString* crypted, QString* sessionID)
     QString lineFeed ="\n";
     int cryptLength = cryptTable.length() - 1;
 
-    QString loc1;
-    int loc2 = 0;
-    QString loc3;
-    int loc10 = 0;
-    bool loc4 = false;
+    QString cryptedChar;
+    int cryptedCharIndex = 0;
+    QString decryptedChar;
+    int tIndex = 0;
+    bool check = false;
     QString result = "";
-    QList<int> loc6;
-    int loc7 = sessionID->length();
-    int loc8 = crypted->length();
+    QList<int> decryptTable;
+    int sessionIdLength = sessionID->length();
+    int cryptedLength = crypted->length();
 
-    loc10 = 0;
-    while (loc10 < loc7) {
-        loc6.append(cryptTable.indexOf(sessionID->at(loc10)));
-        ++loc10;
+    tIndex = 0;
+    while (tIndex < sessionIdLength) {
+        decryptTable.append(cryptTable.indexOf(sessionID->at(tIndex)));
+        ++tIndex;
     }
 
-    int loc11 = 0;
-    loc10 = 0;
-    while (loc11 < loc8) {
-        if (loc10 >= loc7)
-            loc10 = 0;
-        loc1 = crypted->at(loc11);
-        if ((loc2 = cryptTable.indexOf(loc1)) != -1) {
-            if (loc4) {
-                if (loc2 != cryptLength) {
-                    if (loc1 != "\'")
-                        loc2 = loc2 + cryptLength;
+    int pos = 0;
+    tIndex = 0;
+    while (pos < cryptedLength) {
+        if (tIndex >= sessionIdLength)
+            tIndex = 0;
+        cryptedChar = crypted->at(pos);
+        if ((cryptedCharIndex = cryptTable.indexOf(cryptedChar)) != -1) {
+            if (check) {
+                if (cryptedCharIndex != cryptLength) {
+                    if (cryptedChar != "\'")
+                        cryptedCharIndex = cryptedCharIndex + cryptLength;
                     else{
-                        loc3 = doubleQuote;
-                        loc2 = -1;
+                        decryptedChar = doubleQuote;
+                        cryptedCharIndex = -1;
                     }
                 } else {
-                    loc3 = lineFeed;
-                    loc2 = -1;
+                    decryptedChar = lineFeed;
+                    cryptedCharIndex = -1;
                 }
-                loc4 = false;
+                check = false;
             } else {
-                if (loc2 == cryptLength) {
-                    loc4 = true;
-                    loc10 = (loc10 - 1);
-                    loc3 = "";
-                    loc2 = -1;
+                if (cryptedCharIndex == cryptLength) {
+                    check = true;
+                    tIndex = (tIndex - 1);
+                    decryptedChar = "";
+                    cryptedCharIndex = -1;
                 }
             }
         } else
-            loc3 = loc1;
+            decryptedChar = cryptedChar;
 
-        if (loc2 != -1)
-            loc3 = cryptTable.at(loc6[loc10] ^ loc2);
-        result.append(loc3);
-        ++loc11;
-        ++loc10;
+        if (cryptedCharIndex != -1)
+            decryptedChar = cryptTable.at(decryptTable[tIndex] ^ cryptedCharIndex);
+        result.append(decryptedChar);
+        ++pos;
+        ++tIndex;
     }
     return result;
 } // Decrypt
@@ -492,3 +567,35 @@ void VodafoneWidget::AbortRequest()
         m_CurrentReply->abort();
     }
 } // AbortRequest
+
+QStringList VodafoneWidget::GetSims()
+{
+    return m_Sims;
+} // GetSims
+
+QString VodafoneWidget::GetCurrentSim()
+{
+    return m_CurrentSim;
+} // GetCurrentSim
+
+VodafoneWidget::SimType VodafoneWidget::GetCurrentSimType()
+{
+    return m_CurrentSimType;
+} // GetCurrentSimType
+
+bool VodafoneWidget::SetCurrentSim(QString sim)
+{
+    QUrl url("https://widget.vodafone.it/190/trilogy/jsp/swapSim.do");
+    url.addQueryItem("ty_sim", sim);
+    QNetworkRequest request = PrepareRequest(url);
+
+    QString string = SynchRequest(&request);
+    if (DebugXml)
+        qDebug() << "SetCurrentSim: " << string;
+
+    if (!string.contains("parent.location.href=", Qt::CaseInsensitive))
+        return false;
+
+    m_CurrentSim = sim;
+    return true;
+}
