@@ -10,9 +10,7 @@ class ContactWidget : public QScrollArea
 {
     Q_OBJECT
 public:
-    ContactWidget(QWidget *parent = 0, Contact* contact=0);
-
-    bool isMouseOver();
+    ContactWidget(QWidget *parent = 0, Contact* contact=0, QPixmap* defaultImage=0);
 
 private:
     Contact* m_Contact;
