@@ -7,12 +7,13 @@
 #include <QProgressBar>
 
 #include "counter.h"
+#include "settings.h"
 
 class CounterWidget : public QScrollArea
 {
     Q_OBJECT
 public:
-    explicit CounterWidget(QWidget *parent = 0, Counter* counter=0);
+    explicit CounterWidget(QWidget *parent = 0, Counter* counter=0, Settings* settings=0);
     ~CounterWidget();
 private:
     Counter* m_Counter;
@@ -20,7 +21,7 @@ private:
     QWidget* m_Container;
     QGridLayout* m_Layout;
 
-    void CreateWidgets();
+    void CreateWidgets(Settings* settings);
     QString ToHourMinutes(int seconds);
 
 signals:
